.. :changelog:

History
-------

0.1.0 (2013-12-31)
++++++++++++++++++

* First release on PyPI.

0.2.0 (2015-01-08)
++++++++++++++++++

* Added support for Django 1.7 migrations
* Moved common data to abstract base class
* Added common flag filed (aktywny)
* Added 3 model managers to JednostkaAdministracyjna
* Fixed PEP 8 compliance in main source files


0.3.0 (2015-01-06)
++++++++++++++++++

* Added support for Django 1.8 and 1.9
* Added support for SQLite and MySQL/MariaDB
* Python 3.4 compatibility
* Improved test coverage
* This is last version to support Django 1.6 and South

